// this is a very basic template. use it to start writing your own effects.
// if you want effects with lighting start from one of the GouraudXXXX or PhongXXXX effects

// --------------------------------------------------------------------------------------------------
// PARAMETERS:
// --------------------------------------------------------------------------------------------------

//transforms
float4x4 tWVP: WORLDVIEWPROJECTION;

//texture
texture Tex <string uiname="Texture";>;
sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex);          //apply a texture to the sampler
    MipFilter = LINEAR;         //sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

//texture transformation marked with semantic TEXTUREMATRIX to achieve symmetric transformations
float4x4 tTex: TEXTUREMATRIX <string uiname="Texture Transform";>;

//the data structure: "vertexshader to pixelshader"
//used as output data with the VS function
//and as input data with the PS function
struct vs2ps
{
    float4 Pos  : POSITION;
    float2 TexCd : TEXCOORD0;
    float2 TexCd1 : TEXCOORD1;

};

int TextureWidth = 512;
int TextureHeight = 512;

float4 strength;

float2 timedistortion;

#define TWOPI 6.28318531

// --------------------------------------------------------------------------------------------------
// VERTEXSHADERS
// --------------------------------------------------------------------------------------------------
vs2ps VS(
    float4 PosO  : POSITION,
    float4 TexCd : TEXCOORD0
    )
{
    //inititalize all fields of output struct with 0
    vs2ps Out = (vs2ps)0;

    //transform position
    Out.Pos = mul(PosO, tWVP);
    
    //transform texturecoordinates
    Out.TexCd = mul(TexCd, tTex);

    Out.TexCd1 = PosO.xy;
    
    return Out;
}

// --------------------------------------------------------------------------------------------------
// PIXELSHADERS:
// --------------------------------------------------------------------------------------------------

float4 PS(vs2ps In): COLOR
{

       float2 posDistortion = float2(In.TexCd1.x*strength.x+In.TexCd1.y*strength.y, In.TexCd1.x*strength.z+In.TexCd1.y*strength.w);

       float2 angles = float2(posDistortion.x+timedistortion.x*TWOPI,posDistortion.y+timedistortion.y*TWOPI);

       float2 distortion = float2(cos(angles.x),sin(angles.y));

//To address the source texture by pixel, the source texture coordinates
//have to be translated into pixels, which is done with the following formula:
//      dx = 1/TextureWidth;
//      dy = 1/TextureHeight;

//This gives you dx,dy which are the pixel deltas in the UV space of 0-1.
//    distortion *= deltaUV;

     float4 col = tex2D(Samp, In.TexCd + distortion);

    return col;
}

// --------------------------------------------------------------------------------------------------
// TECHNIQUES:
// --------------------------------------------------------------------------------------------------

technique Distort
{
    pass P0
    {
        //Wrap0 = U;  // useful when mesh is round like a sphere
        VertexShader = compile vs_1_1 VS();
        PixelShader  = compile ps_2_0 PS();
    }
}
