// simple contrast sample

// ------------------------------------------------------------------------------------------
// PARAMETERS:
// ------------------------------------------------------------------------------------------

//transforms
float4x4 tW: WORLD;        //the models world matrix
float4x4 tV: VIEW;         //view matrix as set via Renderer (DX9)
float4x4 tP: PROJECTION;
float4x4 tWVP: WORLDVIEWPROJECTION;


//texture
texture Tex <string uiname="Texture";>;
float4x4 tTex <string uiname="Texture Transform";>;  //Texture Transform
sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex);          //apply a texture to the sampler
    MipFilter = LINEAR;         //set the sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

float4x4 tColor <string uiname="Color Transform";>;

// ------------------------------------------------------------------------------------------
// VERTEXSHADERS
// ------------------------------------------------------------------------------------------

struct VS_OUTPUT
{
    float4 PosWVP  : POSITION;
    float2 TexCd : TEXCOORD0;
};

VS_OUTPUT VS(
    float4 PosO  : POSITION,
    float2 TexCd : TEXCOORD)
{
    //inititalize all fields of output struct with 0
    VS_OUTPUT Out = (VS_OUTPUT)0;

    //transform position
    float4 PosWVP = mul(PosO, tWVP);
    //transform texturecoordinates
    TexCd = mul(TexCd, tTex);

    Out.PosWVP  = PosWVP;
    Out.TexCd = TexCd;

    return Out;
}

// --------------------------------------------------------------------------------------------
// PIXELSHADERS:
// --------------------------------------------------------------------------------------------
float4 PS(float2 TexC: TEXCOORD0): COLOR
{
    float4 col = tex2D(Samp, TexC);
    col = mul(col, tColor);
    return col;
}

// --------------------------------------------------------------------------------------------
// TECHNIQUES:
// --------------------------------------------------------------------------------------------

technique TSimpleShader
{
    pass P0
    {
        VertexShader = compile vs_1_0 VS();
        PixelShader  = compile ps_2_0 PS();
    }
}

